@@ -1923,7 +1923,7 @@ class DisplayDrawStringAlign(ISerializable):
         self.x_start    = 0
         self.x_end      = 0
         self.y          = 0
-        self.align      = DisplayAlign.Center
+        self.align      = DisplayAlign.CENTER
         self.font       = DisplayFont.LIBERATION_MONO_5X8
         self.pixel      = DisplayPixel.WHITE
         self.message    = ""
